@@ -330,7 +330,7 @@ static bool show_one_fd(PgSocket *admin, PgSocket *sk)
 	if (!mbuf_get_uint64be(&tmp, &ckey))
 		return false;
 
-	if (sk->pool->db->auth_user && sk->auth_user && !find_user(sk->auth_user->name))
+	if (sk->pool && sk->pool->db->auth_user && sk->auth_user && !find_user(sk->auth_user->name))
 		password = sk->auth_user->passwd;
 
 	/* PAM requires passwords as well since they are not stored externally */
@@ -1275,10 +1275,10 @@ static bool admin_show_help(PgSocket *admin, const char *arg)
 		"sssss",
 		"SNOTICE", "C00000", "MConsole usage",
 		"D\n\tSHOW HELP|CONFIG|DATABASES"
-		"|POOLS|CLIENTS|SERVERS|VERSION\n"
+		"|POOLS|CLIENTS|SERVERS|USERS|VERSION\n"
 		"\tSHOW FDS|SOCKETS|ACTIVE_SOCKETS|LISTS|MEM\n"
 		"\tSHOW DNS_HOSTS|DNS_ZONES\n"
-		"\tSHOW STATS|STATS_TOTALS|STATS_AVERAGES\n"
+		"\tSHOW STATS|STATS_TOTALS|STATS_AVERAGES|TOTALS\n"
 		"\tSET key = arg\n"
 		"\tRELOAD\n"
 		"\tPAUSE [<db>]\n"
