@@ -257,6 +257,21 @@ bool set_pool(PgSocket *client, const char *dbname, const char *username, const
 			return finish_set_pool(client, takeover);
 	}
 
+	/* avoid dealing with invalid data below, and give an
+	 * appropriate error message */
+	if (strlen(username) >= MAX_USERNAME) {
+		disconnect_client(client, true, "username too long");
+		if (cf_log_connections)
+			slog_info(client, "login failed: db=%s user=%s", dbname, username);
+		return false;
+	}
+	if (strlen(password) >= MAX_PASSWORD) {
+		disconnect_client(client, true, "password too long");
+		if (cf_log_connections)
+			slog_info(client, "login failed: db=%s user=%s", dbname, username);
+		return false;
+	}
+
 	/* find user */
 	if (cf_auth_type == AUTH_ANY) {
 		/* ignore requested user */
@@ -374,6 +389,8 @@ bool handle_auth_response(PgSocket *client, PktHdr *pkt) {
 		break;
 	case '2':	/* BindComplete */
 		break;
+	case 'S': /* ParameterStatus */
+		break;
 	case 'Z':	/* ReadyForQuery */
 		sbuf_prepare_skip(&client->link->sbuf, pkt->len);
 		if (!client->auth_user) {
@@ -737,7 +754,7 @@ bool client_proto(SBuf *sbuf, SBufEvent evtype, struct MBuf *data)
 					  hdr2hex(data, hex, sizeof(hex)));
 			return false;
 		}
-		slog_noise(client, "pkt='%c' len=%d", pkt_desc(&pkt), pkt.len);
+		slog_noise(client, "read pkt='%c' len=%d", pkt_desc(&pkt), pkt.len);
 
 		client->request_time = get_cached_time();
 		switch (client->state) {
