@@ -35,7 +35,7 @@
 static const char usage_str[] =
 "Usage: %s [OPTION]... config.ini\n"
 "  -d, --daemon           Run in background (as a daemon)\n"
-"  -R, --restart          Do a online restart\n"
+"  -R, --restart          Do an online restart\n"
 "  -q, --quiet            Run quietly\n"
 "  -v, --verbose          Increase verbosity\n"
 "  -u, --user=<username>  Assume identity of <username>\n"
@@ -582,28 +582,23 @@ static void remove_pidfile(void)
 static void check_pidfile(void)
 {
 	char buf[128 + 1];
-	struct stat st;
 	pid_t pid = 0;
 	int fd, res, err;
 
 	if (!cf_pidfile || !cf_pidfile[0])
 		return;
 
-	/* check if pidfile exists */
-	if (stat(cf_pidfile, &st) < 0) {
-		if (errno != ENOENT)
-			fatal_perror("stat");
-		return;
-	}
-
 	/* read old pid */
 	fd = open(cf_pidfile, O_RDONLY);
-	if (fd < 0)
-		goto locked_pidfile;
+	if (fd < 0) {
+		if (errno == ENOENT)
+			return;
+		fatal_perror("could not open pidfile");
+	}
 	res = read(fd, buf, sizeof(buf) - 1);
 	close(fd);
 	if (res <= 0)
-		goto locked_pidfile;
+		fatal_perror("could not read pidfile");
 
 	/* parse pid */
 	buf[res] = 0;
@@ -621,7 +616,7 @@ static void check_pidfile(void)
 	log_info("stale pidfile, removing");
 	err = unlink(cf_pidfile);
 	if (err != 0)
-		fatal_perror("cannot remove stale pidfile");
+		fatal_perror("could not remove stale pidfile");
 	return;
 
 locked_pidfile:
@@ -683,7 +678,7 @@ static void check_limits(void)
 			fd_count += db->pool_size * total_users;
 	}
 
-	log_info("file descriptor limit: %d (H:%d), max_client_conn: %d, max fds possible: %d",
+	log_info("kernel file descriptor limit: %d (hard: %d); max_client_conn: %d, max expected fd use: %d",
 		 (int)lim.rlim_cur, (int)lim.rlim_max, cf_max_client_conn, fd_count);
 }
 
@@ -894,9 +889,6 @@ int main(int argc, char *argv[])
 	if (getuid() == 0)
 		fatal("PgBouncer should not run as root");
 
-	/* need to do that after loading config */
-	check_limits();
-
 	admin_setup();
 
 	if (cf_reboot) {
@@ -917,6 +909,10 @@ int main(int argc, char *argv[])
 	if (cf_daemon)
 		go_daemon();
 
+	/* need to do that after loading config; also do after
+	 * go_daemon() so that output goes to log file */
+	check_limits();
+
 	/* initialize subsystems, order important */
 	srandom(time(NULL) ^ getpid());
 	if (!event_init())
