@@ -445,7 +445,7 @@ int main(int argc, char *argv[])
 	int i, c;
 	DbConn *db;
 	unsigned seed = time(NULL) ^ getpid();
-	char *cstr = NULL;
+	char *cstr = "";
 	int numcon = 50;
 #ifdef WIN32
 	int wsresult;
@@ -494,10 +494,6 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	if (!cstr) {
-		printf(usage_str);
-		return 1;
-	}
 #ifdef WIN32
         wsresult = WSAStartup(MAKEWORD(2,0),&wsaData);
         if (wsresult != 0)
