@@ -116,7 +116,7 @@ fw_drop_port() {
 		echo "block drop out proto tcp from any to 127.0.0.1 port $1" \
 		    | sudo pfctl -a pgbouncer -f -;;
 	*)
-		echo "Unknown OS";;
+		echo "Unknown OS"; exit 1;;
 	esac
 }
 fw_reject_port() {
@@ -127,7 +127,7 @@ fw_reject_port() {
 		echo "block return-rst out proto tcp from any to 127.0.0.1 port $1" \
 		    | sudo pfctl -a pgbouncer -f -;;
 	*)
-		echo "Unknown OS";;
+		echo "Unknown OS"; exit 1;;
 	esac
 }
 
@@ -164,10 +164,15 @@ admin() {
 }
 
 runtest() {
+	local status
+
 	printf "`date` running $1 ... "
 	eval $1 >$LOGDIR/$1.log 2>&1
-	if [ $? -eq 0 ]; then
+	status=$?
+	if [ $status -eq 0 ]; then
 		echo "ok"
+	elif [ $status -eq 77 ]; then
+		echo "skipped"
 	else
 		echo "FAILED"
 	fi
@@ -177,6 +182,8 @@ runtest() {
 	wait
 	# start with fresh config
 	kill -HUP `cat $BOUNCER_PID`
+
+	return $status
 }
 
 # server_lifetime
@@ -207,6 +214,30 @@ test_query_timeout() {
 	return 0
 }
 
+# idle_transaction_timeout
+test_idle_transaction_timeout() {
+	admin "set pool_mode=transaction"
+	admin "set idle_transaction_timeout=2"
+
+	psql -X --set ON_ERROR_STOP=1 p0 <<-PSQL_EOF
+	begin;
+	\! sleep 3
+	select now();
+	PSQL_EOF
+	test $? -eq 0 && return 1
+
+	# test for GH issue #125
+	psql -X --set ON_ERROR_STOP=1 p0 <<-PSQL_EOF
+	begin;
+	select pg_sleep(1);
+	\! sleep 2
+	select now();
+	PSQL_EOF
+	test $? -ne 0 && return 1
+
+	return 0
+}
+
 # client_idle_timeout
 test_client_idle_timeout() {
 	admin "set client_idle_timeout=2"
@@ -258,7 +289,7 @@ test_server_connect_timeout_establish() {
 
 # server_connect_timeout - block with iptables
 test_server_connect_timeout_reject() {
-	test -z $CAN_SUDO && return 1
+	test -z $CAN_SUDO && return 77
 	admin "set query_timeout=5"
 	admin "set server_connect_timeout=3"
 	fw_drop_port $PG_PORT
@@ -270,7 +301,7 @@ test_server_connect_timeout_reject() {
 
 # server_check_delay
 test_server_check_delay() {
-	test -z $CAN_SUDO && return 1
+	test -z $CAN_SUDO && return 77
 
 	admin "set server_check_delay=2"
 	admin "set server_login_retry=3"
@@ -546,6 +577,7 @@ test_client_idle_timeout
 test_server_lifetime
 test_server_idle_timeout
 test_query_timeout
+test_idle_transaction_timeout
 test_server_connect_timeout_establish
 test_server_connect_timeout_reject
 test_server_check_delay
@@ -566,11 +598,18 @@ if [ $# -gt 0 ]; then
 	testlist=$@
 fi
 
+total_status=0
 for test in $testlist
 do
 	runtest $test
+	status=$?
+	if [ $status -eq 1 ]; then
+		total_status=1
+	fi
 done
 
 complete
 
+exit $total_status
+
 # vim: sts=0 sw=8 noet nosmarttab:
